==> ejc-businessplan-impl-3.0.0-20220722.023953-100-sources.jar: com/ejianc/business/record/vo/RecordbusinessplaneffectdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目商务策划效果变更记录子表
 *
 * @author generator
 *
 */
public class RecordbusinessplaneffectdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mid; // 主表id
    private String sort; // 序号
    private String categoryAndName; // 类别及项目名称
    private String initiateReason; // 立项理由及依据
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date initiateDate; // 立项时间
    private BigDecimal costEstimate; // 成本估算(成本分析)(元)
    private BigDecimal reportAmount; // 上报金额(元)
    private BigDecimal targetAmount; // 策划目标金额(元)
    private BigDecimal completeAmount; // 已完成目标金额(元)
    private BigDecimal estimateProfits; // 预计利润(元)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date proposedCompleteTime; // 拟完成时间节点
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date completeTime; // 完成时间
    private String supportingDetails; // 证明资料明细
    private BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    private String firstResponsiblePerson; // 第一责任人
    private String mainResponsiblePerson; // 主要负责人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date finalCompleteTime; // (最后)完成时间
    private String attention; // 推荐情况、存在问题、注意事项
    private BigDecimal supervisionNotReportedMoney; // 监理未上报金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date supervisionNotReportedTime; // 监理未上报预计上报时间
    private BigDecimal supervisionReportedMoney; // 监理已上报未批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date supervisionReportedTime; // 监理已上报未批复上报时间
    private BigDecimal supervisionApprovedMoney; // 监理已批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date supervisionApprovedTime; // 监理已批复上报时间
    private BigDecimal ownerNotReportedMoney; // 业主未上报金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ownerNotReportedTime; // 业主未上报预计上报时间
    private BigDecimal ownerReportedMoney; // 业主已上报未批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ownerReportedTime; // 业主已上报未批复上报时间
    private BigDecimal ownerApprovedMoney; // 业主已批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ownerApprovedTime; // 业主已批复上报时间
    private BigDecimal approvedMoney; // 已批复金额
    private BigDecimal pricedMoney; // 已计价金额
    private BigDecimal pricedActualMoney; // 已计价部分实际金额
    private BigDecimal pricedPartBenefit; // 已计价部分的效益
    private String remarks; // 备注
    private String tid; // 表格行id
    private String tpid; // 表格行父id
    private String toThismonthProgress; // 公司截至本月进度
    private String planCategory; // 策划类别
    private String planType; // 策划类型
    private BigDecimal incomeBeforePlan; // 策划前收入 （万元）
    private BigDecimal costBeforePlan; // 策划前成本（万元）
    private BigDecimal benefitBeforePlan; // 策划前效益（万元）
    private BigDecimal estimatedRevenueAfterPlan; // 策划后预计收入（万元）
    private BigDecimal estimatedCostAfterPlan; // 策划后预计成本（万元）
    private BigDecimal estimatedBenefitsAfterPlan; // 策划后预计效益（万元）
    private BigDecimal planExpectAchieveResults; // 策划预计创效（万元）
    private BigDecimal revenueAfterPlan; // 策划后收入（万元）
    private BigDecimal actualCost; // 实际成本（万元）
    private BigDecimal benefitAfterPlan; // 策划后效益（万元）
    private BigDecimal includePlannedActualEffect; // 其中：策划实际创效（万元）

    private List<RecordbusinessplaneffectdetailVO> children = new ArrayList<>();


    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }
    public String getCategoryAndName() {
        return categoryAndName;
    }

    public void setCategoryAndName(String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    public String getInitiateReason() {
        return initiateReason;
    }

    public void setInitiateReason(String initiateReason) {
        this.initiateReason = initiateReason;
    }
    public Date getInitiateDate() {
        return initiateDate;
    }

    public void setInitiateDate(Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    public BigDecimal getCostEstimate() {
        return costEstimate;
    }

    public void setCostEstimate(BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    public BigDecimal getReportAmount() {
        return reportAmount;
    }

    public void setReportAmount(BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    public BigDecimal getTargetAmount() {
        return targetAmount;
    }

    public void setTargetAmount(BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    public BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    public void setCompleteAmount(BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    public BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    public void setEstimateProfits(BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    public Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    public void setProposedCompleteTime(Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    public Date getCompleteTime() {
        return completeTime;
    }

    public void setCompleteTime(Date completeTime) {
        this.completeTime = completeTime;
    }
    public String getSupportingDetails() {
        return supportingDetails;
    }

    public void setSupportingDetails(String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    public BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    public void setReportToThismonthProgress(BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    public String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    public void setFirstResponsiblePerson(String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    public String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    public void setMainResponsiblePerson(String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    public Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    public void setFinalCompleteTime(Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    public String getAttention() {
        return attention;
    }

    public void setAttention(String attention) {
        this.attention = attention;
    }
    public BigDecimal getSupervisionNotReportedMoney() {
        return supervisionNotReportedMoney;
    }

    public void setSupervisionNotReportedMoney(BigDecimal supervisionNotReportedMoney) {
        this.supervisionNotReportedMoney = supervisionNotReportedMoney;
    }
    public Date getSupervisionNotReportedTime() {
        return supervisionNotReportedTime;
    }

    public void setSupervisionNotReportedTime(Date supervisionNotReportedTime) {
        this.supervisionNotReportedTime = supervisionNotReportedTime;
    }
    public BigDecimal getSupervisionReportedMoney() {
        return supervisionReportedMoney;
    }

    public void setSupervisionReportedMoney(BigDecimal supervisionReportedMoney) {
        this.supervisionReportedMoney = supervisionReportedMoney;
    }
    public Date getSupervisionReportedTime() {
        return supervisionReportedTime;
    }

    public void setSupervisionReportedTime(Date supervisionReportedTime) {
        this.supervisionReportedTime = supervisionReportedTime;
    }
    public BigDecimal getSupervisionApprovedMoney() {
        return supervisionApprovedMoney;
    }

    public void setSupervisionApprovedMoney(BigDecimal supervisionApprovedMoney) {
        this.supervisionApprovedMoney = supervisionApprovedMoney;
    }
    public Date getSupervisionApprovedTime() {
        return supervisionApprovedTime;
    }

    public void setSupervisionApprovedTime(Date supervisionApprovedTime) {
        this.supervisionApprovedTime = supervisionApprovedTime;
    }
    public BigDecimal getOwnerNotReportedMoney() {
        return ownerNotReportedMoney;
    }

    public void setOwnerNotReportedMoney(BigDecimal ownerNotReportedMoney) {
        this.ownerNotReportedMoney = ownerNotReportedMoney;
    }
    public Date getOwnerNotReportedTime() {
        return ownerNotReportedTime;
    }

    public void setOwnerNotReportedTime(Date ownerNotReportedTime) {
        this.ownerNotReportedTime = ownerNotReportedTime;
    }
    public BigDecimal getOwnerReportedMoney() {
        return ownerReportedMoney;
    }

    public void setOwnerReportedMoney(BigDecimal ownerReportedMoney) {
        this.ownerReportedMoney = ownerReportedMoney;
    }
    public Date getOwnerReportedTime() {
        return ownerReportedTime;
    }

    public void setOwnerReportedTime(Date ownerReportedTime) {
        this.ownerReportedTime = ownerReportedTime;
    }
    public BigDecimal getOwnerApprovedMoney() {
        return ownerApprovedMoney;
    }

    public void setOwnerApprovedMoney(BigDecimal ownerApprovedMoney) {
        this.ownerApprovedMoney = ownerApprovedMoney;
    }
    public Date getOwnerApprovedTime() {
        return ownerApprovedTime;
    }

    public void setOwnerApprovedTime(Date ownerApprovedTime) {
        this.ownerApprovedTime = ownerApprovedTime;
    }
    public BigDecimal getApprovedMoney() {
        return approvedMoney;
    }

    public void setApprovedMoney(BigDecimal approvedMoney) {
        this.approvedMoney = approvedMoney;
    }
    public BigDecimal getPricedMoney() {
        return pricedMoney;
    }

    public void setPricedMoney(BigDecimal pricedMoney) {
        this.pricedMoney = pricedMoney;
    }
    public BigDecimal getPricedActualMoney() {
        return pricedActualMoney;
    }

    public void setPricedActualMoney(BigDecimal pricedActualMoney) {
        this.pricedActualMoney = pricedActualMoney;
    }
    public BigDecimal getPricedPartBenefit() {
        return pricedPartBenefit;
    }

    public void setPricedPartBenefit(BigDecimal pricedPartBenefit) {
        this.pricedPartBenefit = pricedPartBenefit;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }
    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    public String getToThismonthProgress() {
        return toThismonthProgress;
    }

    public void setToThismonthProgress(String toThismonthProgress) {
        this.toThismonthProgress = toThismonthProgress;
    }
    public String getPlanCategory() {
        return planCategory;
    }

    public void setPlanCategory(String planCategory) {
        this.planCategory = planCategory;
    }
    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }
    public BigDecimal getIncomeBeforePlan() {
        return incomeBeforePlan;
    }

    public void setIncomeBeforePlan(BigDecimal incomeBeforePlan) {
        this.incomeBeforePlan = incomeBeforePlan;
    }
    public BigDecimal getCostBeforePlan() {
        return costBeforePlan;
    }

    public void setCostBeforePlan(BigDecimal costBeforePlan) {
        this.costBeforePlan = costBeforePlan;
    }
    public BigDecimal getBenefitBeforePlan() {
        return benefitBeforePlan;
    }

    public void setBenefitBeforePlan(BigDecimal benefitBeforePlan) {
        this.benefitBeforePlan = benefitBeforePlan;
    }
    public BigDecimal getEstimatedRevenueAfterPlan() {
        return estimatedRevenueAfterPlan;
    }

    public void setEstimatedRevenueAfterPlan(BigDecimal estimatedRevenueAfterPlan) {
        this.estimatedRevenueAfterPlan = estimatedRevenueAfterPlan;
    }
    public BigDecimal getEstimatedCostAfterPlan() {
        return estimatedCostAfterPlan;
    }

    public void setEstimatedCostAfterPlan(BigDecimal estimatedCostAfterPlan) {
        this.estimatedCostAfterPlan = estimatedCostAfterPlan;
    }
    public BigDecimal getEstimatedBenefitsAfterPlan() {
        return estimatedBenefitsAfterPlan;
    }

    public void setEstimatedBenefitsAfterPlan(BigDecimal estimatedBenefitsAfterPlan) {
        this.estimatedBenefitsAfterPlan = estimatedBenefitsAfterPlan;
    }
    public BigDecimal getPlanExpectAchieveResults() {
        return planExpectAchieveResults;
    }

    public void setPlanExpectAchieveResults(BigDecimal planExpectAchieveResults) {
        this.planExpectAchieveResults = planExpectAchieveResults;
    }
    public BigDecimal getRevenueAfterPlan() {
        return revenueAfterPlan;
    }

    public void setRevenueAfterPlan(BigDecimal revenueAfterPlan) {
        this.revenueAfterPlan = revenueAfterPlan;
    }
    public BigDecimal getActualCost() {
        return actualCost;
    }

    public void setActualCost(BigDecimal actualCost) {
        this.actualCost = actualCost;
    }
    public BigDecimal getBenefitAfterPlan() {
        return benefitAfterPlan;
    }

    public void setBenefitAfterPlan(BigDecimal benefitAfterPlan) {
        this.benefitAfterPlan = benefitAfterPlan;
    }
    public BigDecimal getIncludePlannedActualEffect() {
        return includePlannedActualEffect;
    }

    public void setIncludePlannedActualEffect(BigDecimal includePlannedActualEffect) {
        this.includePlannedActualEffect = includePlannedActualEffect;
    }

    public List<RecordbusinessplaneffectdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<RecordbusinessplaneffectdetailVO> children) {
        this.children = children;
    }
}

==> ejc-businessplan-impl-3.0.0-20240729.071255-184-sources.jar: com/ejianc/business/record/vo/RecordbusinessplaneffectdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目商务策划效果变更记录子表
 *
 * @author generator
 *
 */
public class RecordbusinessplaneffectdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mid; // 主表id
    private String sort; // 序号
    private String categoryAndName; // 类别及项目名称
    private String initiateReason; // 立项理由及依据
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date initiateDate; // 立项时间
    private BigDecimal costEstimate; // 成本估算(成本分析)(元)
    private BigDecimal reportAmount; // 上报金额(元)
    private BigDecimal targetAmount; // 策划目标金额(元)
    private BigDecimal completeAmount; // 已完成目标金额(元)
    private BigDecimal estimateProfits; // 预计利润(元)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date proposedCompleteTime; // 拟完成时间节点
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date completeTime; // 完成时间
    private String supportingDetails; // 证明资料明细
    private BigDecimal reportToThismonthProgress; // 报公司截至本月进度(元)
    private String firstResponsiblePerson; // 第一责任人
    private String mainResponsiblePerson; // 主要负责人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date finalCompleteTime; // (最后)完成时间
    private String attention; // 推荐情况、存在问题、注意事项
    private BigDecimal supervisionNotReportedMoney; // 监理未上报金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date supervisionNotReportedTime; // 监理未上报预计上报时间
    private BigDecimal supervisionReportedMoney; // 监理已上报未批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date supervisionReportedTime; // 监理已上报未批复上报时间
    private BigDecimal supervisionApprovedMoney; // 监理已批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date supervisionApprovedTime; // 监理已批复上报时间
    private BigDecimal ownerNotReportedMoney; // 业主未上报金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ownerNotReportedTime; // 业主未上报预计上报时间
    private BigDecimal ownerReportedMoney; // 业主已上报未批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ownerReportedTime; // 业主已上报未批复上报时间
    private BigDecimal ownerApprovedMoney; // 业主已批复金额
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date ownerApprovedTime; // 业主已批复上报时间
    private BigDecimal approvedMoney; // 已批复金额
    private BigDecimal pricedMoney; // 已计价金额
    private BigDecimal pricedActualMoney; // 已计价部分实际金额
    private BigDecimal pricedPartBenefit; // 已计价部分的效益
    private String remarks; // 备注
    private String tid; // 表格行id
    private String tpid; // 表格行父id
    private String toThismonthProgress; // 公司截至本月进度
    private String planCategory; // 策划类别
    private String planType; // 策划类型
    private BigDecimal incomeBeforePlan; // 策划前收入 （万元）
    private BigDecimal costBeforePlan; // 策划前成本（万元）
    private BigDecimal benefitBeforePlan; // 策划前效益（万元）
    private BigDecimal estimatedRevenueAfterPlan; // 策划后预计收入（万元）
    private BigDecimal estimatedCostAfterPlan; // 策划后预计成本（万元）
    private BigDecimal estimatedBenefitsAfterPlan; // 策划后预计效益（万元）
    private BigDecimal planExpectAchieveResults; // 策划预计创效（万元）
    private BigDecimal revenueAfterPlan; // 策划后收入（万元）
    private BigDecimal actualCost; // 实际成本（万元）
    private BigDecimal benefitAfterPlan; // 策划后效益（万元）
    private BigDecimal includePlannedActualEffect; // 其中：策划实际创效（万元）
    private java.lang.String planStatus; // 策划状态


    private List<RecordbusinessplaneffectdetailVO> children = new ArrayList<>();

    public String getPlanStatus() {
        return planStatus;
    }

    public void setPlanStatus(String planStatus) {
        this.planStatus = planStatus;
    }
    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }
    public String getCategoryAndName() {
        return categoryAndName;
    }

    public void setCategoryAndName(String categoryAndName) {
        this.categoryAndName = categoryAndName;
    }
    public String getInitiateReason() {
        return initiateReason;
    }

    public void setInitiateReason(String initiateReason) {
        this.initiateReason = initiateReason;
    }
    public Date getInitiateDate() {
        return initiateDate;
    }

    public void setInitiateDate(Date initiateDate) {
        this.initiateDate = initiateDate;
    }
    public BigDecimal getCostEstimate() {
        return costEstimate;
    }

    public void setCostEstimate(BigDecimal costEstimate) {
        this.costEstimate = costEstimate;
    }
    public BigDecimal getReportAmount() {
        return reportAmount;
    }

    public void setReportAmount(BigDecimal reportAmount) {
        this.reportAmount = reportAmount;
    }
    public BigDecimal getTargetAmount() {
        return targetAmount;
    }

    public void setTargetAmount(BigDecimal targetAmount) {
        this.targetAmount = targetAmount;
    }
    public BigDecimal getCompleteAmount() {
        return completeAmount;
    }

    public void setCompleteAmount(BigDecimal completeAmount) {
        this.completeAmount = completeAmount;
    }
    public BigDecimal getEstimateProfits() {
        return estimateProfits;
    }

    public void setEstimateProfits(BigDecimal estimateProfits) {
        this.estimateProfits = estimateProfits;
    }
    public Date getProposedCompleteTime() {
        return proposedCompleteTime;
    }

    public void setProposedCompleteTime(Date proposedCompleteTime) {
        this.proposedCompleteTime = proposedCompleteTime;
    }
    public Date getCompleteTime() {
        return completeTime;
    }

    public void setCompleteTime(Date completeTime) {
        this.completeTime = completeTime;
    }
    public String getSupportingDetails() {
        return supportingDetails;
    }

    public void setSupportingDetails(String supportingDetails) {
        this.supportingDetails = supportingDetails;
    }
    public BigDecimal getReportToThismonthProgress() {
        return reportToThismonthProgress;
    }

    public void setReportToThismonthProgress(BigDecimal reportToThismonthProgress) {
        this.reportToThismonthProgress = reportToThismonthProgress;
    }
    public String getFirstResponsiblePerson() {
        return firstResponsiblePerson;
    }

    public void setFirstResponsiblePerson(String firstResponsiblePerson) {
        this.firstResponsiblePerson = firstResponsiblePerson;
    }
    public String getMainResponsiblePerson() {
        return mainResponsiblePerson;
    }

    public void setMainResponsiblePerson(String mainResponsiblePerson) {
        this.mainResponsiblePerson = mainResponsiblePerson;
    }
    public Date getFinalCompleteTime() {
        return finalCompleteTime;
    }

    public void setFinalCompleteTime(Date finalCompleteTime) {
        this.finalCompleteTime = finalCompleteTime;
    }
    public String getAttention() {
        return attention;
    }

    public void setAttention(String attention) {
        this.attention = attention;
    }
    public BigDecimal getSupervisionNotReportedMoney() {
        return supervisionNotReportedMoney;
    }

    public void setSupervisionNotReportedMoney(BigDecimal supervisionNotReportedMoney) {
        this.supervisionNotReportedMoney = supervisionNotReportedMoney;
    }
    public Date getSupervisionNotReportedTime() {
        return supervisionNotReportedTime;
    }

    public void setSupervisionNotReportedTime(Date supervisionNotReportedTime) {
        this.supervisionNotReportedTime = supervisionNotReportedTime;
    }
    public BigDecimal getSupervisionReportedMoney() {
        return supervisionReportedMoney;
    }

    public void setSupervisionReportedMoney(BigDecimal supervisionReportedMoney) {
        this.supervisionReportedMoney = supervisionReportedMoney;
    }
    public Date getSupervisionReportedTime() {
        return supervisionReportedTime;
    }

    public void setSupervisionReportedTime(Date supervisionReportedTime) {
        this.supervisionReportedTime = supervisionReportedTime;
    }
    public BigDecimal getSupervisionApprovedMoney() {
        return supervisionApprovedMoney;
    }

    public void setSupervisionApprovedMoney(BigDecimal supervisionApprovedMoney) {
        this.supervisionApprovedMoney = supervisionApprovedMoney;
    }
    public Date getSupervisionApprovedTime() {
        return supervisionApprovedTime;
    }

    public void setSupervisionApprovedTime(Date supervisionApprovedTime) {
        this.supervisionApprovedTime = supervisionApprovedTime;
    }
    public BigDecimal getOwnerNotReportedMoney() {
        return ownerNotReportedMoney;
    }

    public void setOwnerNotReportedMoney(BigDecimal ownerNotReportedMoney) {
        this.ownerNotReportedMoney = ownerNotReportedMoney;
    }
    public Date getOwnerNotReportedTime() {
        return ownerNotReportedTime;
    }

    public void setOwnerNotReportedTime(Date ownerNotReportedTime) {
        this.ownerNotReportedTime = ownerNotReportedTime;
    }
    public BigDecimal getOwnerReportedMoney() {
        return ownerReportedMoney;
    }

    public void setOwnerReportedMoney(BigDecimal ownerReportedMoney) {
        this.ownerReportedMoney = ownerReportedMoney;
    }
    public Date getOwnerReportedTime() {
        return ownerReportedTime;
    }

    public void setOwnerReportedTime(Date ownerReportedTime) {
        this.ownerReportedTime = ownerReportedTime;
    }
    public BigDecimal getOwnerApprovedMoney() {
        return ownerApprovedMoney;
    }

    public void setOwnerApprovedMoney(BigDecimal ownerApprovedMoney) {
        this.ownerApprovedMoney = ownerApprovedMoney;
    }
    public Date getOwnerApprovedTime() {
        return ownerApprovedTime;
    }

    public void setOwnerApprovedTime(Date ownerApprovedTime) {
        this.ownerApprovedTime = ownerApprovedTime;
    }
    public BigDecimal getApprovedMoney() {
        return approvedMoney;
    }

    public void setApprovedMoney(BigDecimal approvedMoney) {
        this.approvedMoney = approvedMoney;
    }
    public BigDecimal getPricedMoney() {
        return pricedMoney;
    }

    public void setPricedMoney(BigDecimal pricedMoney) {
        this.pricedMoney = pricedMoney;
    }
    public BigDecimal getPricedActualMoney() {
        return pricedActualMoney;
    }

    public void setPricedActualMoney(BigDecimal pricedActualMoney) {
        this.pricedActualMoney = pricedActualMoney;
    }
    public BigDecimal getPricedPartBenefit() {
        return pricedPartBenefit;
    }

    public void setPricedPartBenefit(BigDecimal pricedPartBenefit) {
        this.pricedPartBenefit = pricedPartBenefit;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }
    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    public String getToThismonthProgress() {
        return toThismonthProgress;
    }

    public void setToThismonthProgress(String toThismonthProgress) {
        this.toThismonthProgress = toThismonthProgress;
    }
    public String getPlanCategory() {
        return planCategory;
    }

    public void setPlanCategory(String planCategory) {
        this.planCategory = planCategory;
    }
    public String getPlanType() {
        return planType;
    }

    public void setPlanType(String planType) {
        this.planType = planType;
    }
    public BigDecimal getIncomeBeforePlan() {
        return incomeBeforePlan;
    }

    public void setIncomeBeforePlan(BigDecimal incomeBeforePlan) {
        this.incomeBeforePlan = incomeBeforePlan;
    }
    public BigDecimal getCostBeforePlan() {
        return costBeforePlan;
    }

    public void setCostBeforePlan(BigDecimal costBeforePlan) {
        this.costBeforePlan = costBeforePlan;
    }
    public BigDecimal getBenefitBeforePlan() {
        return benefitBeforePlan;
    }

    public void setBenefitBeforePlan(BigDecimal benefitBeforePlan) {
        this.benefitBeforePlan = benefitBeforePlan;
    }
    public BigDecimal getEstimatedRevenueAfterPlan() {
        return estimatedRevenueAfterPlan;
    }

    public void setEstimatedRevenueAfterPlan(BigDecimal estimatedRevenueAfterPlan) {
        this.estimatedRevenueAfterPlan = estimatedRevenueAfterPlan;
    }
    public BigDecimal getEstimatedCostAfterPlan() {
        return estimatedCostAfterPlan;
    }

    public void setEstimatedCostAfterPlan(BigDecimal estimatedCostAfterPlan) {
        this.estimatedCostAfterPlan = estimatedCostAfterPlan;
    }
    public BigDecimal getEstimatedBenefitsAfterPlan() {
        return estimatedBenefitsAfterPlan;
    }

    public void setEstimatedBenefitsAfterPlan(BigDecimal estimatedBenefitsAfterPlan) {
        this.estimatedBenefitsAfterPlan = estimatedBenefitsAfterPlan;
    }
    public BigDecimal getPlanExpectAchieveResults() {
        return planExpectAchieveResults;
    }

    public void setPlanExpectAchieveResults(BigDecimal planExpectAchieveResults) {
        this.planExpectAchieveResults = planExpectAchieveResults;
    }
    public BigDecimal getRevenueAfterPlan() {
        return revenueAfterPlan;
    }

    public void setRevenueAfterPlan(BigDecimal revenueAfterPlan) {
        this.revenueAfterPlan = revenueAfterPlan;
    }
    public BigDecimal getActualCost() {
        return actualCost;
    }

    public void setActualCost(BigDecimal actualCost) {
        this.actualCost = actualCost;
    }
    public BigDecimal getBenefitAfterPlan() {
        return benefitAfterPlan;
    }

    public void setBenefitAfterPlan(BigDecimal benefitAfterPlan) {
        this.benefitAfterPlan = benefitAfterPlan;
    }
    public BigDecimal getIncludePlannedActualEffect() {
        return includePlannedActualEffect;
    }

    public void setIncludePlannedActualEffect(BigDecimal includePlannedActualEffect) {
        this.includePlannedActualEffect = includePlannedActualEffect;
    }

    public List<RecordbusinessplaneffectdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<RecordbusinessplaneffectdetailVO> children) {
        this.children = children;
    }
}
